#pragma once

#define WM_OK				0       //成功
#define WM_FAIL				-1      //失败
#define WM_INIT_FAIL		-101    //初始化设备失败
#define WM_FREE_FAIL		-102	//释放设备失败
#define WM_OPEN_FAIL		-103	//打开设备失败
#define WM_AUTHEN_FAIL		-104	//设备验证失败
#define WM_CLOSE_FAIL		-105	//关闭设备失败
#define WM_GETIMG_FAIL		-106    //获取图像失败
#define WM_IMG_TIMEOUT		-107    //获取图像超时
#define WM_EXTRACT_FAIL		-110	//提取特征失败
#define WM_GENTEMP_FAIL		-111	//合成模板失败
#define WM_VERIFY_FAIL		-112	//比对失败
#define WM_IMGCONVERT_FAIL  -113	//图像转换失败
#define WM_FEACONVERT_FAIL  -114	//特征转换失败
#define WM_NOFIND_CARD  	-115	//未检测到TF卡
#define WM_READ_FAIL 		-116	//读卡失败
#define WM_WRITE_FAIL		-117	//写卡失败
#define WM_OPENED_FAIL		-118	//多个应用打开设备失败

#define WM_PARAMETER_ERROR	-120	//参数传入错误
#define WM_LIC_OUT			-121	//授权过期

/*==================================================================================
功能： 初始化设备。
参数： 无
返回： 0:表示调用成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_Init ();

/*==================================================================================
功能： 释放设备。
参数： 无
返回： 0:表示调用成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_Free ();

/*==================================================================================
功能： 得到当前型号指纹采集设备个数。
参数： 无
返回： 设备个数
==================================================================================*/
int  WM_GetDeviceCount();

/*==================================================================================
功能： 打开当前指定的设备，目前只支持打开一个指纹设备。
参数： [in] nDevIndex: 指纹采集设备索引号，nDevIndex为0表示打开第一个设备。
[out] DevHandle: 设备句柄
返回： 0:表示打开设备成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_OpenDevice (int nDevIndex , int* DevHandle);

/*==================================================================================
功能： 关闭某个设备。
参数： [in]DevHandle： 设备句柄。
返回： 0:表示关闭设备成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_CloseDevice (int DevHandle);

/*==================================================================================
功能： 获取指纹采集设备序列号。
参数： [in] DevHandle： 设备句柄；
[out] DeviceSN：输出设备序列号，由调用者申请内存。
返回： 0: 表示获取设备序列号成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_GetSerialNumber (int DevHandle,unsigned char* DeviceSN);

/*==================================================================================
功能： 获取指纹图像信息。
参数： [out] ImageWidth：图像宽度；
[out] ImageHeight：图像高度。
返回： 0: 表示获取图像信息成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_GetImageInfo(int* ImageWidth,int* ImageHeight);

/*==================================================================================
功能： 获取指纹采集图像。
参数： [in] DevHandle： 设备句柄；
[in] nTimeOut：取图像超时时间，单位为毫秒, 具体为：
0：立即返回；
>0：等待时间。
[out] ImageBuf：获取的图像缓冲区，格式为RAW，由调用者申请内存，大小为：图像宽度* 图像高度；
[out] Size: 返回的图像数据大小。
返回： 0：表示获取指纹图像成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_GetImage(int DevHandle,  int nTimeOut,
					  unsigned char *ImageBuf, int *Size);

/*==================================================================================
功能： 从指纹图像中提取指纹特征。
参数： [in] ImageBuf： 指纹RAW图像；
[in] ImageWidth：传入指纹图像数据的宽度；
[in] ImageHeight：传入指纹图像数据的高度；
[out] Feature：指纹特征缓冲区，由调用者申请内存；
[out] Size: 返回的指纹特征数据大小。
返回： 0：表示提取指纹特征成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_Extract ( unsigned char * ImageBuf,
					  int ImageWidth,
					  int ImageHeight,
					  unsigned char * Feature,
					  int * Size );

/*==================================================================================
功能： 根据三幅指纹图像的特征合成指纹模板。
参数： [in] Feature1，Feature2，Feature3，分别表示3个特征；
[out] Template：获取模板缓冲区，由调用者申请内存；
[out] Size: 返回的指纹模板数据大小。
返回： 0：表示合成指纹模板成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int WM_GenTemplateWithImage(unsigned char *Image1[10],
	int nCount,
	int nWidth,
	int nHeight,
	unsigned char *Template,
	int * Size);

/*==================================================================================
功能： 获取的特征与传入的模板进行比对。
参数： [in] Template：传入指纹模板数据；
[in] Feature：传入指纹特征数据；
[out] Score：比对相似度。
返回： 0：表示比对成功；
其它:比对失败。
==================================================================================*/
int  WM_Verify ( unsigned char *Template,
					 unsigned char * Feature,
					 int *Score);

/*==================================================================================
功能： 获取的特征与传入的身份证模板进行比对。
参数： [in] Template：传入身份证模板数据；
[in] Feature：传入指纹特征数据；
[out] Score：比对相似度。
返回： 0：表示比对成功；
其它:比对失败。
==================================================================================*/
int  WM_CIDVerify ( unsigned char *Template,
					 unsigned char * Feature,
					 int *Score);

/*==================================================================================
功能： 将指纹图像从RAW格式转换为BMP格式。
参数： [in] RawImageBuf：传入RAW格式指纹图像数据；
[in] ImageWidth：传入指纹图像数据的宽度；
[in] ImageHeight：传入指纹图像数据的高度；
[out] BmpImageBuf：获取BMP格式图像的缓冲区，由调用者申请内存，大小一般为：图像宽度×图像高度+1078；
[out] Size：返回图像数据的大小。
返回： 0:表示调用成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_RawToBMP ( unsigned char *RawImageBuf,
					   int ImageWidth,
					   int ImageHeight,
					   unsigned char *BmpImageBuf,
					   int *Size);


/*==================================================================================
功能： 从指纹BMP图像中提取指纹特征。
参数： [in] BmpImageBuf： 指纹BMP图像；
[in] ImageWidth：传入指纹图像数据的宽度；
[in] ImageHeight：传入指纹图像数据的高度；
[out] Feature：指纹特征缓冲区，由调用者申请内存；
[out] Size: 返回的指纹特征数据大小。
返回： 0：表示提取指纹特征成功；
其它:调用失败，具体参数“错误码定义”。
==================================================================================*/
int  WM_BmpImage2Feature(unsigned char *BmpImageBuf, int ImageWidth,int ImageHeight,unsigned char *Feature, int *Size);

